<template>
    <v-dialog transition="dialog-top-transition" v-model="show" :persistent="persistent" :max-width="maxWidth">
        <v-card>
            <v-toolbar :color="headerColor === 'question' ? 'primary' : headerColor" dense dark>
                <v-toolbar-title tag="small">
                    <small class="text-truncate" v-html="title"/>
                </v-toolbar-title>
            </v-toolbar>
            <!--@todo Add custom icon e.g., success, info, warning, error-->
            <v-card-text>
                <v-row justify="space-between">
                    <v-col class="ma-2" cols="1" align-self="center" v-if="icon">
                        <v-icon small color="warning" v-if="icon === 'warning' || icon === 'warn'">mdi-alert</v-icon>
                        <v-icon small color="error" v-else-if="icon === 'error'">mdi-fire</v-icon>
                        <v-icon small color="info" v-else-if="icon === 'info'">mdi-information-outline</v-icon>
                        <v-icon small color="success" v-else-if="icon === 'success'">mdi-check-circle</v-icon>
                        <v-icon small color="primary" v-else>mdi-chat-question</v-icon>
                    </v-col>
                    <v-col class="mt-3" v-html="message"/>
                </v-row>
            </v-card-text>


            <v-divider class="mx-0 my-0"/>
            <v-card-actions>
                <v-btn small color="darken-1" v-show="showCancel" :color="cancelColor" text @click="cancelInternal">
                    {{ cancelText }}
                </v-btn>
                <v-spacer/>
                <v-btn small color="darken-1" :color="confirmColor !== 'question' ? confirmColor : 'success'" text
                       @click="confirmInternal">
                    {{ confirmText }}
                </v-btn>
            </v-card-actions>
        </v-card>
    </v-dialog>
</template>

<script>
import {mapState} from 'vuex'

export default {
    name: 'ConfirmDialog',
    data() {
        return {}
    },
    computed: {
        ...mapState({
            show: state => state.Confirm.show,
            title: state => state.Confirm.title,
            message: state => state.Confirm.message,
            confirm: state => state.Confirm.actionConfirm,
            cancel: state => state.Confirm.actionCancel,
            confirmText: state => state.Confirm.confirmText,
            cancelText: state => state.Confirm.cancelText,
            confirmColor: state => state.Confirm.confirmColor,
            cancelColor: state => state.Confirm.cancelColor,
            showCancel: state => state.Confirm.showCancel,
            headerColor: state => state.Confirm.headerColor,
            onMount: state => state.Confirm.onMount,
            icon: state => state.Confirm.icon,
            maxWidth: state => state.Confirm.width,
            persistent: state => state.Confirm.persistent,
        })
    },
    watch: {
        show(value) {
            if (value && typeof this.onMount === 'function') {
                this.onMount()
            }
        }
    },
    methods: {
        async confirmInternal() {
            await this.$store.commit('Confirm/SET_SHOW', false)
            await this.confirm()
        },
        async cancelInternal() {
            await this.cancel()
            await this.$store.commit('Confirm/SET_SHOW', false)
        }
    }
}
</script>

<style>
.v-dialog {
    /*overflow: hidden;*/
}
</style>
